@@ -1,22 +1,18 @@
 if (("DESeq2" %in% rownames(installed.packages()) == FALSE) || (!require("DESeq2", quietly = TRUE))) {
     install.packages("png")
-
-    tryCatch(
-    {install.packages("XML")
-    require("XML")},
-    warning = function(e) {
-    install.packages("XML", type = "binary")},
-    error = function(e) {
-    install.packages("XML", type = "binary")})
-
-    tryCatch(
-    {install.packages("vctrs")
-    require("vctrs")},
-    warning = function(e) {
-    install.packages("vctrs", type = "binary")},
-    error = function(e) {
-    install.packages("vctrs", type = "binary")})
-
+    pgks <- list("XML", "vctrs", "RCurl")
+    for (pkg in pgks) {
+        tryCatch(
+            tryCatch(
+            {install.packages(pkg)
+            require(pkg)},
+            warning = function(e) {
+            install.packages(pkg, type = "binary")},
+            error = function(e) {
+            install.packages(pkg, type = "binary")}),
+        error = function(e) {}
+        )
+}
     if (!require("BiocManager", quietly = TRUE)) {
         install.packages("BiocManager")
         }
