@@ -347,9 +347,10 @@ class AltTQDM(QtCore.QObject):
         super().__init__()
 
     def __iter__(self):
+        self.update(0)
         for i, item in enumerate(self.tqdm):
-            self.barUpdate.emit(1)
             yield item
+            self.update(1)
         self.barFinished.emit()
 
     def __enter__(self):
@@ -381,7 +382,7 @@ class AltParallel(QtCore.QObject):
         self.prev_total = 0
         self.prev_report = 0
         super().__init__()
-        self.barUpdate.emit(1)
+        self.barUpdate.emit(0)
 
     def __call__(self, *args, **kwargs):
         parallel_backend('multiprocessing')
@@ -552,6 +553,12 @@ class ComboBoxOrOtherWidget(QtWidgets.QWidget):
             return get_val_from_widget(self.other)
         return self.combo.currentText()
 
+    def setValue(self, value):
+        if value in self.items:
+            self.combo.setCurrentText(value)
+        else:
+            set_widget_value(self.other, value)
+
 
 class HelpButton(QtWidgets.QToolButton):
     __slots__ = {'param_name': 'name of the parameter',
@@ -871,6 +878,12 @@ class OrderedFileList(MultiChoiceListWithDeleteReorder):
     def get_sorted_names(self):
         return [name for name in self.items]
 
+    def setValue(self, items):
+        assert validation.isiterable(items) and validation.isinstanceiter(items, str), \
+            f"Invalid type for 'items': {type(items)}."
+        self.delete_all_quietly()
+        self.add_items(items)
+
 
 class MandatoryComboBox(QtWidgets.QComboBox):
     __slots__ = {'default_choice': 'default choice'}
@@ -1160,7 +1173,7 @@ class OptionalWidget(QtWidgets.QWidget):
         self.layout = QtWidgets.QHBoxLayout(self)
         self.other = other
         self.default = default
-        self.checkbox = QtWidgets.QCheckBox('Disable input?')
+        self.checkbox = QtWidgets.QCheckBox('Disable this parameter?')
         self.toggled = self.checkbox.toggled
 
         self.init_ui()
@@ -1192,8 +1205,8 @@ class OptionalWidget(QtWidgets.QWidget):
             self.checkbox.setChecked(True)
         else:
             try:
+                set_widget_value(self.other, val)
                 self.checkbox.setChecked(False)
-                self.other.setValue(val)
             except AttributeError:
                 raise ValueError(f'Unable to set default value of {type(self.other)} to {val}')
 
@@ -1598,6 +1611,19 @@ class NewParam:
         self.default = default
 
 
+def set_widget_value(widget: QtWidgets.QWidget, value):
+    if hasattr(widget, 'setValue'):
+        widget.setValue(value)
+    elif hasattr(widget, 'setText'):
+        widget.setText(value)
+    elif hasattr(widget, 'setChecked'):
+        widget.setChecked(value)
+    elif hasattr(widget, 'setCurrentText'):
+        widget.setCurrentText(value)
+    else:
+        raise AttributeError(f'cannot set value for widget of type {type(widget)}.')
+
+
 def param_to_widget(param, name: str,
                     actions_to_connect: Union[Iterable[Callable], Callable] = tuple(), pipeline_mode: bool = False):
     column_annotations = {param_typing.GroupedColumns: TableColumnGroupPicker,
