@@ -137,6 +137,21 @@ def cache_gui_file(item: Union[pd.DataFrame, set, str], filename: str):
         raise TypeError(type(item))
 
 
+def check_changed_version():
+    filename = get_gui_cache_dir().joinpath('latest_version.txt')
+    if not filename.exists():
+        return True
+
+    with open(filename) as f:
+        ver = f.read()
+    current_ver = __version__
+    # update latest version to current version
+    with open(filename, 'w') as f:
+        f.write(current_ver)
+
+    return ver != current_ver
+
+
 def save_gui_session(session_filename: Union[str, Path], file_names: List[str], item_names: List[str], item_types: list,
                      item_properties: list, pipeline_names: List[str], pipeline_files: List[str]):
     session_filename = Path(session_filename)
@@ -245,9 +260,12 @@ def load_csv(filename: Union[str, Path], index_col: int = None, drop_columns: Un
     df = pd.read_csv(filename, **kwargs)
     if squeeze:
         df = df.squeeze("columns")
+
+    if index_col is not None:
+        df.index = df.index.astype('str')
     df.index = [ind.strip() if isinstance(ind, str) else ind for ind in df.index]
     if isinstance(df, pd.DataFrame):
-        df.columns = [col.strip() if isinstance(col, str) else col for col in df.columns]
+        df.columns = [col.strip() if isinstance(col, str) else str(col).strip() for col in df.columns]
 
         for col in df.columns:
             # check if the columns contains string data
@@ -896,8 +914,8 @@ class GeneIDTranslator:
             return False
 
 
-def submit_id_mapping(url: str, from_db: str, to_db: str, ids: List[str]):
-    req = requests.post(f"{url}/idmapping/run", data={"from": from_db, "to": to_db, "ids": ",".join(ids)})
+def submit_id_mapping(session: requests.Session, url: str, from_db: str, to_db: str, ids: List[str]):
+    req = session.post(f"{url}/idmapping/run", data={"from": from_db, "to": to_db, "ids": ",".join(ids)})
     req.raise_for_status()
     return req.json()["jobId"]
 
@@ -1000,7 +1018,7 @@ def print_progress_batches(batch_index, size, total):
 
 def get_mapping_results(api_url: str, from_db: str, to_db: str, ids: List[str], polling_interval: float, session,
                         verbose: bool = True):
-    job_id = submit_id_mapping(api_url, from_db=from_db, to_db=to_db, ids=ids)
+    job_id = submit_id_mapping(session, api_url, from_db=from_db, to_db=to_db, ids=ids)
     if check_id_mapping_results_ready(session, api_url, job_id, polling_interval, verbose=verbose):
         link = get_id_mapping_results_link(session, api_url, job_id)
         results = get_id_mapping_results_search(session, link, verbose)
@@ -1073,7 +1091,9 @@ def map_gene_ids(ids: Union[str, Iterable[str]], map_from: str, map_to: str = 'U
 
         retries = Retry(total=5, backoff_factor=0.25, status_forcelist=[500, 502, 503, 504])
         session = requests.Session()
-        session.mount("https://", HTTPAdapter(max_retries=retries))
+        adapter = HTTPAdapter(max_retries=retries)
+        session.mount("http://", adapter)
+        session.mount("https://", adapter)
 
         results = get_mapping_results(api_url=API_URL, from_db=id_dict_from[map_from], to_db=id_dict_to[map_to],
                                       ids=ids,
@@ -1354,7 +1374,7 @@ async def get_gui_videos(video_filenames: Tuple[str, ...]):  # pragma: no cover
                 i += 1
                 await asyncio.gather(task)
 
-    except aiohttp.ClientConnectorError:
+    except (aiohttp.ClientConnectorError, asyncio.TimeoutError):
         pass
 
 
