@@ -241,7 +241,7 @@ def parse_docstring(docstring: str) -> Tuple[str, Dict[str, str]]:
     split = docstring.split('\n\n')
     desc = split[0]
     params_str = split[1]
-    free_text_match = '["#\w\s\.\(\)\-\:%\*=@!\?\+\_,/' + "'" + ']'
+    free_text_match = '["#\w\s\.\(\)\-\:%\*=@!\?\+\_,/`><\[\]' + "'" + ']'
     params_matches = list(
         re.finditer('^:param ([a-zA-Z_0-9]+):(' + free_text_match + '+?)(?=^\:.*\:)', params_str, re.MULTILINE))
     params = {match.group(1): match.group(2).replace('. ', '. \n') for match in params_matches}
